"""_2904.py

CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse
"""


from typing import List

from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _2771
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.compound import _2884
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_CENTRAL_BEARING_CONNECTION_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses.Compound', 'CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse',)


class CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse(_2884.CoaxialConnectionCompoundSteadyStateSynchronousResponse):
    """CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse

    This is a mastapy class.
    """

    TYPE = _CYCLOIDAL_DISC_CENTRAL_BEARING_CONNECTION_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_analysis_cases_ready(self) -> 'List[_2771.CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponse]':
        """List[CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponse]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def connection_analysis_cases(self) -> 'List[_2771.CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponse]':
        """List[CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponse]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_1607.py

SQLDatabase
"""


from typing import Generic, TypeVar

from mastapy.utility.databases import _1602, _1605, _1601
from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SQL_DATABASE = python_net_import('SMT.MastaAPI.Utility.Databases', 'SQLDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('SQLDatabase',)


TKey = TypeVar('TKey', bound='_1602.DatabaseKey')
TValue = TypeVar('TValue', bound='_0.APIBase')


class SQLDatabase(_1601.Database['TKey', 'TValue'], Generic[TKey, TValue]):
    """SQLDatabase

    This is a mastapy class.

    Generic Types:
        TKey
        TValue
    """

    TYPE = _SQL_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SQLDatabase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    def delete(self, key: '_1602.DatabaseKey'):
        """ 'Delete' is the original name of this method.

        Args:
            key (mastapy.utility.databases.DatabaseKey)
        """

        self.wrapped.Delete(key.wrapped if key else None)

    def save(self, item: '_1605.NamedDatabaseItem'):
        """ 'Save' is the original name of this method.

        Args:
            item (mastapy.utility.databases.NamedDatabaseItem)
        """

        self.wrapped.Save(item.wrapped if item else None)



"""_3342.py

RootAssemblySteadyStateSynchronousResponseAtASpeed
"""


from mastapy.system_model.part_model import _2224
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3353, _3255
from mastapy._internal.python_net import python_net_import

_ROOT_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'RootAssemblySteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('RootAssemblySteadyStateSynchronousResponseAtASpeed',)


class RootAssemblySteadyStateSynchronousResponseAtASpeed(_3255.AssemblySteadyStateSynchronousResponseAtASpeed):
    """RootAssemblySteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    """

    TYPE = _ROOT_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RootAssemblySteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2224.RootAssembly':
        """RootAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def steady_state_synchronous_response_at_a_speed_inputs(self) -> '_3353.SteadyStateSynchronousResponseAtASpeed':
        """SteadyStateSynchronousResponseAtASpeed: 'SteadyStateSynchronousResponseAtASpeedInputs' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SteadyStateSynchronousResponseAtASpeedInputs
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_7092.py

RingPinsToDiscConnectionAdvancedSystemDeflection
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.system_model.connections_and_sockets.cycloidal import _2092
from mastapy.system_model.analyses_and_results.static_loads import _6671
from mastapy.system_model.analyses_and_results.system_deflections import _2539
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7066
from mastapy._internal.python_net import python_net_import

_RING_PINS_TO_DISC_CONNECTION_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'RingPinsToDiscConnectionAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('RingPinsToDiscConnectionAdvancedSystemDeflection',)


class RingPinsToDiscConnectionAdvancedSystemDeflection(_7066.InterMountableComponentConnectionAdvancedSystemDeflection):
    """RingPinsToDiscConnectionAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE = _RING_PINS_TO_DISC_CONNECTION_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RingPinsToDiscConnectionAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def average_number_of_pins_in_contact(self) -> 'float':
        """float: 'AverageNumberOfPinsInContact' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AverageNumberOfPinsInContact
        return temp

    @property
    def maximum_contact_stress(self) -> 'float':
        """float: 'MaximumContactStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumContactStress
        return temp

    @property
    def connection_design(self) -> '_2092.RingPinsToDiscConnection':
        """RingPinsToDiscConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_load_case(self) -> '_6671.RingPinsToDiscConnectionLoadCase':
        """RingPinsToDiscConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_system_deflection_results(self) -> 'List[_2539.RingPinsToDiscConnectionSystemDeflection]':
        """List[RingPinsToDiscConnectionSystemDeflection]: 'ConnectionSystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionSystemDeflectionResults
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_1780.py

LoadedNeedleRollerBearingRow
"""


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling import _1779, _1768
from mastapy._internal.python_net import python_net_import

_LOADED_NEEDLE_ROLLER_BEARING_ROW = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedNeedleRollerBearingRow')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedNeedleRollerBearingRow',)


class LoadedNeedleRollerBearingRow(_1768.LoadedCylindricalRollerBearingRow):
    """LoadedNeedleRollerBearingRow

    This is a mastapy class.
    """

    TYPE = _LOADED_NEEDLE_ROLLER_BEARING_ROW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedNeedleRollerBearingRow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cage_land_sliding_power_loss(self) -> 'float':
        """float: 'CageLandSlidingPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CageLandSlidingPowerLoss
        return temp

    @property
    def rolling_power_loss(self) -> 'float':
        """float: 'RollingPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RollingPowerLoss
        return temp

    @property
    def rolling_power_loss_traction_coefficient(self) -> 'float':
        """float: 'RollingPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RollingPowerLossTractionCoefficient
        return temp

    @property
    def sliding_power_loss(self) -> 'float':
        """float: 'SlidingPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlidingPowerLoss
        return temp

    @property
    def sliding_power_loss_traction_coefficient(self) -> 'float':
        """float: 'SlidingPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlidingPowerLossTractionCoefficient
        return temp

    @property
    def total_power_loss(self) -> 'float':
        """float: 'TotalPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalPowerLoss
        return temp

    @property
    def total_power_loss_traction_coefficient(self) -> 'float':
        """float: 'TotalPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalPowerLossTractionCoefficient
        return temp

    @property
    def loaded_bearing(self) -> '_1779.LoadedNeedleRollerBearingResults':
        """LoadedNeedleRollerBearingResults: 'LoadedBearing' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadedBearing
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1197 import CustomSplineHalfDesign
    from ._1198 import CustomSplineJointDesign
    from ._1199 import DetailedSplineJointSettings
    from ._1200 import DIN5480SplineHalfDesign
    from ._1201 import DIN5480SplineJointDesign
    from ._1202 import DudleyEffectiveLengthApproximationOption
    from ._1203 import FitTypes
    from ._1204 import GBT3478SplineHalfDesign
    from ._1205 import GBT3478SplineJointDesign
    from ._1206 import HeatTreatmentTypes
    from ._1207 import ISO4156SplineHalfDesign
    from ._1208 import ISO4156SplineJointDesign
    from ._1209 import JISB1603SplineJointDesign
    from ._1210 import ManufacturingTypes
    from ._1211 import Modules
    from ._1212 import PressureAngleTypes
    from ._1213 import RootTypes
    from ._1214 import SAEFatigueLifeFactorTypes
    from ._1215 import SAESplineHalfDesign
    from ._1216 import SAESplineJointDesign
    from ._1217 import SAETorqueCycles
    from ._1218 import SplineDesignTypes
    from ._1219 import FinishingMethods
    from ._1220 import SplineFitClassType
    from ._1221 import SplineFixtureTypes
    from ._1222 import SplineHalfDesign
    from ._1223 import SplineJointDesign
    from ._1224 import SplineMaterial
    from ._1225 import SplineRatingTypes
    from ._1226 import SplineToleranceClassTypes
    from ._1227 import StandardSplineHalfDesign
    from ._1228 import StandardSplineJointDesign



"""_7128.py

WormGearSetAdvancedSystemDeflection
"""


from typing import List

from mastapy.system_model.part_model.gears import _2301
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6712
from mastapy.gears.rating.worm import _348
from mastapy.system_model.analyses_and_results.system_deflections import _2581
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7126, _7127, _7061
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'WormGearSetAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetAdvancedSystemDeflection',)


class WormGearSetAdvancedSystemDeflection(_7061.GearSetAdvancedSystemDeflection):
    """WormGearSetAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_SET_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2301.WormGearSet':
        """WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_load_case(self) -> '_6712.WormGearSetLoadCase':
        """WormGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def rating(self) -> '_348.WormGearSetRating':
        """WormGearSetRating: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Rating
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_detailed_analysis(self) -> '_348.WormGearSetRating':
        """WormGearSetRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDetailedAnalysis
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_system_deflection_results(self) -> 'List[_2581.WormGearSetSystemDeflection]':
        """List[WormGearSetSystemDeflection]: 'AssemblySystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblySystemDeflectionResults
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def worm_gears_advanced_system_deflection(self) -> 'List[_7126.WormGearAdvancedSystemDeflection]':
        """List[WormGearAdvancedSystemDeflection]: 'WormGearsAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormGearsAdvancedSystemDeflection
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def worm_meshes_advanced_system_deflection(self) -> 'List[_7127.WormGearMeshAdvancedSystemDeflection]':
        """List[WormGearMeshAdvancedSystemDeflection]: 'WormMeshesAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormMeshesAdvancedSystemDeflection
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._374 import SpiralBevelGearMeshRating
    from ._375 import SpiralBevelGearRating
    from ._376 import SpiralBevelGearSetRating



"""_1781.py

LoadedNonBarrelRollerBearingDutyCycle
"""


from mastapy._internal import constructor
from mastapy.bearings.bearing_results import _1722
from mastapy._internal.python_net import python_net_import

_LOADED_NON_BARREL_ROLLER_BEARING_DUTY_CYCLE = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedNonBarrelRollerBearingDutyCycle')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedNonBarrelRollerBearingDutyCycle',)


class LoadedNonBarrelRollerBearingDutyCycle(_1722.LoadedRollingBearingDutyCycle):
    """LoadedNonBarrelRollerBearingDutyCycle

    This is a mastapy class.
    """

    TYPE = _LOADED_NON_BARREL_ROLLER_BEARING_DUTY_CYCLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedNonBarrelRollerBearingDutyCycle.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def smt_rib_stress_safety_factor(self) -> 'float':
        """float: 'SMTRibStressSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SMTRibStressSafetyFactor
        return temp



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._961 import AddendumModificationDistributionRule
    from ._962 import BacklashSpecification
    from ._963 import BasicRackProfiles
    from ._964 import CaseHardeningProperties
    from ._965 import CreateNewSuitableCutterOption
    from ._966 import CrossedAxisCylindricalGearPair
    from ._967 import CrossedAxisCylindricalGearPairLineContact
    from ._968 import CrossedAxisCylindricalGearPairPointContact
    from ._969 import CylindricalGearAbstractRack
    from ._970 import CylindricalGearAbstractRackFlank
    from ._971 import CylindricalGearBasicRack
    from ._972 import CylindricalGearBasicRackFlank
    from ._973 import CylindricalGearCuttingOptions
    from ._974 import CylindricalGearDefaults
    from ._975 import CylindricalGearDesign
    from ._976 import CylindricalGearDesignConstraint
    from ._977 import CylindricalGearDesignConstraints
    from ._978 import CylindricalGearDesignConstraintsDatabase
    from ._979 import CylindricalGearDesignConstraintSettings
    from ._980 import CylindricalGearDesignSettings
    from ._981 import CylindricalGearFlankDesign
    from ._982 import CylindricalGearMeshDesign
    from ._983 import CylindricalGearMeshFlankDesign
    from ._984 import CylindricalGearMicroGeometrySettings
    from ._985 import CylindricalGearPinionTypeCutter
    from ._986 import CylindricalGearPinionTypeCutterFlank
    from ._987 import CylindricalGearProfileMeasurement
    from ._988 import CylindricalGearProfileMeasurementType
    from ._989 import CylindricalGearProfileModifications
    from ._990 import CylindricalGearSetDesign
    from ._991 import CylindricalGearSetFlankDesign
    from ._992 import CylindricalGearSetMacroGeometryOptimiser
    from ._993 import CylindricalGearSetManufacturingConfigurationSelection
    from ._994 import CylindricalGearTableMGItemDetail
    from ._995 import CylindricalGearTableWithMGCharts
    from ._996 import CylindricalGearToothThicknessSpecification
    from ._997 import CylindricalMeshAngularBacklash
    from ._998 import CylindricalMeshedGear
    from ._999 import CylindricalMeshedGearFlank
    from ._1000 import CylindricalMeshLinearBacklashSpecification
    from ._1001 import CylindricalPlanetaryGearSetDesign
    from ._1002 import CylindricalPlanetGearDesign
    from ._1003 import DIN3967AllowanceSeries
    from ._1004 import DIN3967ToleranceSeries
    from ._1005 import DoubleAxisScaleAndRange
    from ._1006 import FinishStockSpecification
    from ._1007 import FinishToothThicknessDesignSpecification
    from ._1008 import GearFitSystems
    from ._1009 import GearManufacturingConfigSetupViewModel
    from ._1010 import GearSetManufacturingConfigurationSetup
    from ._1011 import GeometrySpecificationType
    from ._1012 import HardenedMaterialProperties
    from ._1013 import HardnessProfileCalculationMethod
    from ._1014 import HeatTreatmentType
    from ._1015 import ISO6336Geometry
    from ._1016 import ISO6336GeometryBase
    from ._1017 import ISO6336GeometryForShapedGears
    from ._1018 import ISO6336GeometryManufactured
    from ._1019 import LinearBacklashSepcification
    from ._1020 import LTCALoadCaseModifiableSettings
    from ._1021 import LtcaSettings
    from ._1022 import MicroGeometryConvention
    from ._1023 import MicroGeometryProfileConvention
    from ._1024 import Micropitting
    from ._1025 import NamedPlanetAssemblyIndex
    from ._1026 import NamedPlanetSideBandAmplitudeFactor
    from ._1027 import ReadonlyToothThicknessSpecification
    from ._1028 import RelativeMeasurementViewModel
    from ._1029 import RelativeValuesSpecification
    from ._1030 import RootStressSurfaceChartOption
    from ._1031 import Scuffing
    from ._1032 import ScuffingCoefficientOfFrictionMethods
    from ._1033 import ScuffingTemperatureMethodsAGMA
    from ._1034 import ScuffingTemperatureMethodsISO
    from ._1035 import ShaperEdgeTypes
    from ._1036 import SpurGearLoadSharingCodes
    from ._1037 import StandardRack
    from ._1038 import StandardRackFlank
    from ._1039 import SurfaceRoughness
    from ._1040 import ThicknessType
    from ._1041 import TiffAnalysisSettings
    from ._1042 import TipAlterationCoefficientMethod
    from ._1043 import TolerancedMetalMeasurements
    from ._1044 import TolerancedValueSpecification
    from ._1045 import ToothFlankFractureAnalysisSettings
    from ._1046 import ToothThicknessSpecification
    from ._1047 import ToothThicknessSpecificationBase
    from ._1048 import TypeOfMechanismHousing
    from ._1049 import Usage



"""_4677.py

PartToPartShearCouplingModalAnalysisAtAStiffness
"""


from mastapy.system_model.part_model.couplings import _2337
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6658
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4633
from mastapy._internal.python_net import python_net_import

_PART_TO_PART_SHEAR_COUPLING_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness', 'PartToPartShearCouplingModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('PartToPartShearCouplingModalAnalysisAtAStiffness',)


class PartToPartShearCouplingModalAnalysisAtAStiffness(_4633.CouplingModalAnalysisAtAStiffness):
    """PartToPartShearCouplingModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE = _PART_TO_PART_SHEAR_COUPLING_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PartToPartShearCouplingModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2337.PartToPartShearCoupling':
        """PartToPartShearCoupling: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_load_case(self) -> '_6658.PartToPartShearCouplingLoadCase':
        """PartToPartShearCouplingLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_5391.py

ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis
"""


from typing import List

from mastapy.system_model.part_model.gears import _2303
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5256
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5389, _5390, _5281
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis',)


class ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis(_5281.BevelGearSetCompoundMultibodyDynamicsAnalysis):
    """ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _ZEROL_BEVEL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2303.ZerolBevelGearSet':
        """ZerolBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2303.ZerolBevelGearSet':
        """ZerolBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5256.ZerolBevelGearSetMultibodyDynamicsAnalysis]':
        """List[ZerolBevelGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def zerol_bevel_gears_compound_multibody_dynamics_analysis(self) -> 'List[_5389.ZerolBevelGearCompoundMultibodyDynamicsAnalysis]':
        """List[ZerolBevelGearCompoundMultibodyDynamicsAnalysis]: 'ZerolBevelGearsCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ZerolBevelGearsCompoundMultibodyDynamicsAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def zerol_bevel_meshes_compound_multibody_dynamics_analysis(self) -> 'List[_5390.ZerolBevelGearMeshCompoundMultibodyDynamicsAnalysis]':
        """List[ZerolBevelGearMeshCompoundMultibodyDynamicsAnalysis]: 'ZerolBevelMeshesCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ZerolBevelMeshesCompoundMultibodyDynamicsAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5256.ZerolBevelGearSetMultibodyDynamicsAnalysis]':
        """List[ZerolBevelGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_333.py

GearRating
"""


from mastapy.materials import (
    _254, _226, _229, _230
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating import _328, _326
from mastapy._internal.python_net import python_net_import

_GEAR_RATING = python_net_import('SMT.MastaAPI.Gears.Rating', 'GearRating')


__docformat__ = 'restructuredtext en'
__all__ = ('GearRating',)


class GearRating(_326.AbstractGearRating):
    """GearRating

    This is a mastapy class.
    """

    TYPE = _GEAR_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bending_safety_factor_results(self) -> '_254.SafetyFactorItem':
        """SafetyFactorItem: 'BendingSafetyFactorResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.BendingSafetyFactorResults
        if _254.SafetyFactorItem.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast bending_safety_factor_results to SafetyFactorItem. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def contact_safety_factor_results(self) -> '_254.SafetyFactorItem':
        """SafetyFactorItem: 'ContactSafetyFactorResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ContactSafetyFactorResults
        if _254.SafetyFactorItem.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast contact_safety_factor_results to SafetyFactorItem. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def static_safety_factor(self) -> '_328.BendingAndContactReportingObject':
        """BendingAndContactReportingObject: 'StaticSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StaticSafetyFactor
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_1906.py

CylindricalRollerBearing
"""


from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.bearings.bearing_results import _1706
from mastapy.bearings.bearing_designs.rolling import _1917
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_ROLLER_BEARING = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.Rolling', 'CylindricalRollerBearing')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalRollerBearing',)


class CylindricalRollerBearing(_1917.NonBarrelRollerBearing):
    """CylindricalRollerBearing

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_ROLLER_BEARING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalRollerBearing.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def allowable_axial_load_factor(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'AllowableAxialLoadFactor' is the original name of this property."""

        temp = self.wrapped.AllowableAxialLoadFactor
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @allowable_axial_load_factor.setter
    def allowable_axial_load_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.AllowableAxialLoadFactor = value

    @property
    def capacity_lubrication_factor_for_permissible_axial_load_grease(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'CapacityLubricationFactorForPermissibleAxialLoadGrease' is the original name of this property."""

        temp = self.wrapped.CapacityLubricationFactorForPermissibleAxialLoadGrease
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @capacity_lubrication_factor_for_permissible_axial_load_grease.setter
    def capacity_lubrication_factor_for_permissible_axial_load_grease(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.CapacityLubricationFactorForPermissibleAxialLoadGrease = value

    @property
    def capacity_lubrication_factor_for_permissible_axial_load_oil(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'CapacityLubricationFactorForPermissibleAxialLoadOil' is the original name of this property."""

        temp = self.wrapped.CapacityLubricationFactorForPermissibleAxialLoadOil
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @capacity_lubrication_factor_for_permissible_axial_load_oil.setter
    def capacity_lubrication_factor_for_permissible_axial_load_oil(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.CapacityLubricationFactorForPermissibleAxialLoadOil = value

    @property
    def diameter_exponent_factor_for_permissible_axial_load(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'DiameterExponentFactorForPermissibleAxialLoad' is the original name of this property."""

        temp = self.wrapped.DiameterExponentFactorForPermissibleAxialLoad
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @diameter_exponent_factor_for_permissible_axial_load.setter
    def diameter_exponent_factor_for_permissible_axial_load(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.DiameterExponentFactorForPermissibleAxialLoad = value

    @property
    def diameter_scaling_factor_for_permissible_axial_load(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'DiameterScalingFactorForPermissibleAxialLoad' is the original name of this property."""

        temp = self.wrapped.DiameterScalingFactorForPermissibleAxialLoad
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @diameter_scaling_factor_for_permissible_axial_load.setter
    def diameter_scaling_factor_for_permissible_axial_load(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.DiameterScalingFactorForPermissibleAxialLoad = value

    @property
    def permissible_axial_load_default_calculation_method(self) -> '_1706.CylindricalRollerMaxAxialLoadMethod':
        """CylindricalRollerMaxAxialLoadMethod: 'PermissibleAxialLoadDefaultCalculationMethod' is the original name of this property."""

        temp = self.wrapped.PermissibleAxialLoadDefaultCalculationMethod
        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1706.CylindricalRollerMaxAxialLoadMethod)(value) if value is not None else None

    @permissible_axial_load_default_calculation_method.setter
    def permissible_axial_load_default_calculation_method(self, value: '_1706.CylindricalRollerMaxAxialLoadMethod'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.PermissibleAxialLoadDefaultCalculationMethod = value

    @property
    def permissible_axial_load_dimension_factor(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'PermissibleAxialLoadDimensionFactor' is the original name of this property."""

        temp = self.wrapped.PermissibleAxialLoadDimensionFactor
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @permissible_axial_load_dimension_factor.setter
    def permissible_axial_load_dimension_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.PermissibleAxialLoadDimensionFactor = value

    @property
    def permissible_axial_load_internal_dimension_factor(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'PermissibleAxialLoadInternalDimensionFactor' is the original name of this property."""

        temp = self.wrapped.PermissibleAxialLoadInternalDimensionFactor
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @permissible_axial_load_internal_dimension_factor.setter
    def permissible_axial_load_internal_dimension_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.PermissibleAxialLoadInternalDimensionFactor = value

    @property
    def radial_load_lubrication_factor_for_permissible_axial_load_grease(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'RadialLoadLubricationFactorForPermissibleAxialLoadGrease' is the original name of this property."""

        temp = self.wrapped.RadialLoadLubricationFactorForPermissibleAxialLoadGrease
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @radial_load_lubrication_factor_for_permissible_axial_load_grease.setter
    def radial_load_lubrication_factor_for_permissible_axial_load_grease(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.RadialLoadLubricationFactorForPermissibleAxialLoadGrease = value

    @property
    def radial_load_lubrication_factor_for_permissible_axial_load_oil(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'RadialLoadLubricationFactorForPermissibleAxialLoadOil' is the original name of this property."""

        temp = self.wrapped.RadialLoadLubricationFactorForPermissibleAxialLoadOil
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @radial_load_lubrication_factor_for_permissible_axial_load_oil.setter
    def radial_load_lubrication_factor_for_permissible_axial_load_oil(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.RadialLoadLubricationFactorForPermissibleAxialLoadOil = value

    @property
    def reference_rotation_speed(self) -> 'float':
        """float: 'ReferenceRotationSpeed' is the original name of this property."""

        temp = self.wrapped.ReferenceRotationSpeed
        return temp

    @reference_rotation_speed.setter
    def reference_rotation_speed(self, value: 'float'):
        self.wrapped.ReferenceRotationSpeed = float(value) if value else 0.0



"""_118.py

EntityVectorState
"""


from mastapy._internal import constructor
from mastapy.math_utility import (
    _1332, _1316, _1330, _1342
)
from mastapy._internal.cast_exception import CastException
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ENTITY_VECTOR_STATE = python_net_import('SMT.MastaAPI.NodalAnalysis.States', 'EntityVectorState')


__docformat__ = 'restructuredtext en'
__all__ = ('EntityVectorState',)


class EntityVectorState(_0.APIBase):
    """EntityVectorState

    This is a mastapy class.
    """

    TYPE = _ENTITY_VECTOR_STATE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'EntityVectorState.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def degrees_of_freedom_per_entity(self) -> 'int':
        """int: 'DegreesOfFreedomPerEntity' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DegreesOfFreedomPerEntity
        return temp

    @property
    def number_of_entities(self) -> 'int':
        """int: 'NumberOfEntities' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NumberOfEntities
        return temp

    @property
    def vector(self) -> '_1332.RealVector':
        """RealVector: 'Vector' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Vector
        if _1332.RealVector.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast vector to RealVector. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_3339.py

RollingRingAssemblySteadyStateSynchronousResponseAtASpeed
"""


from mastapy.system_model.part_model.couplings import _2346
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6672
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3346
from mastapy._internal.python_net import python_net_import

_ROLLING_RING_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'RollingRingAssemblySteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingRingAssemblySteadyStateSynchronousResponseAtASpeed',)


class RollingRingAssemblySteadyStateSynchronousResponseAtASpeed(_3346.SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed):
    """RollingRingAssemblySteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    """

    TYPE = _ROLLING_RING_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingRingAssemblySteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2346.RollingRingAssembly':
        """RollingRingAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_load_case(self) -> '_6672.RollingRingAssemblyLoadCase':
        """RollingRingAssemblyLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_6127.py

WormGearMeshDynamicAnalysis
"""


from mastapy.system_model.connections_and_sockets.gears import _2080
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6711
from mastapy.system_model.analyses_and_results.dynamic_analyses import _6062
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_MESH_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses', 'WormGearMeshDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearMeshDynamicAnalysis',)


class WormGearMeshDynamicAnalysis(_6062.GearMeshDynamicAnalysis):
    """WormGearMeshDynamicAnalysis

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_MESH_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearMeshDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2080.WormGearMesh':
        """WormGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_load_case(self) -> '_6711.WormGearMeshLoadCase':
        """WormGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_1288.py

LoadedBolt
"""


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.bolts import (
    _1271, _1287, _1293, _1283
)
from mastapy._math.vector_3d import Vector3D
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_LOADED_BOLT = python_net_import('SMT.MastaAPI.Bolts', 'LoadedBolt')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedBolt',)


class LoadedBolt(_0.APIBase):
    """LoadedBolt

    This is a mastapy class.
    """

    TYPE = _LOADED_BOLT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedBolt.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def additional_axial_bolt_load(self) -> 'float':
        """float: 'AdditionalAxialBoltLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AdditionalAxialBoltLoad
        return temp

    @property
    def additional_axial_bolt_load_in_assembled_state(self) -> 'float':
        """float: 'AdditionalAxialBoltLoadInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AdditionalAxialBoltLoadInAssembledState
        return temp

    @property
    def additional_bending_moment(self) -> 'float':
        """float: 'AdditionalBendingMoment' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AdditionalBendingMoment
        return temp

    @property
    def additional_bending_moment_in_bolt(self) -> 'float':
        """float: 'AdditionalBendingMomentInBolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AdditionalBendingMomentInBolt
        return temp

    @property
    def additional_bolt_load_after_opening(self) -> 'float':
        """float: 'AdditionalBoltLoadAfterOpening' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AdditionalBoltLoadAfterOpening
        return temp

    @property
    def alternating_stress(self) -> 'float':
        """float: 'AlternatingStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AlternatingStress
        return temp

    @property
    def alternating_stress_eccentric(self) -> 'float':
        """float: 'AlternatingStressEccentric' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AlternatingStressEccentric
        return temp

    @property
    def assembly_preload(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'AssemblyPreload' is the original name of this property."""

        temp = self.wrapped.AssemblyPreload
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @assembly_preload.setter
    def assembly_preload(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.AssemblyPreload = value

    @property
    def assembly_temperature(self) -> 'float':
        """float: 'AssemblyTemperature' is the original name of this property."""

        temp = self.wrapped.AssemblyTemperature
        return temp

    @assembly_temperature.setter
    def assembly_temperature(self, value: 'float'):
        self.wrapped.AssemblyTemperature = float(value) if value else 0.0

    @property
    def average_bolt_load(self) -> 'float':
        """float: 'AverageBoltLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AverageBoltLoad
        return temp

    @property
    def average_bolt_load_maximum_assembly_preload(self) -> 'float':
        """float: 'AverageBoltLoadMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AverageBoltLoadMaximumAssemblyPreload
        return temp

    @property
    def average_bolt_load_minimum_assembly_preload(self) -> 'float':
        """float: 'AverageBoltLoadMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AverageBoltLoadMinimumAssemblyPreload
        return temp

    @property
    def axial_load_type(self) -> '_1271.AxialLoadType':
        """AxialLoadType: 'AxialLoadType' is the original name of this property."""

        temp = self.wrapped.AxialLoadType
        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1271.AxialLoadType)(value) if value is not None else None

    @axial_load_type.setter
    def axial_load_type(self, value: '_1271.AxialLoadType'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.AxialLoadType = value

    @property
    def axial_load_at_opening_limit_concentric_loading(self) -> 'float':
        """float: 'AxialLoadAtOpeningLimitConcentricLoading' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AxialLoadAtOpeningLimitConcentricLoading
        return temp

    @property
    def axial_load_at_opening_limit_eccentric_loading(self) -> 'float':
        """float: 'AxialLoadAtOpeningLimitEccentricLoading' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AxialLoadAtOpeningLimitEccentricLoading
        return temp

    @property
    def axial_load_at_opening_limit_eccentric_loading_from_5329(self) -> 'float':
        """float: 'AxialLoadAtOpeningLimitEccentricLoadingFrom5329' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AxialLoadAtOpeningLimitEccentricLoadingFrom5329
        return temp

    @property
    def axial_load_at_which_opening_occurs_during_eccentric_loading(self) -> 'float':
        """float: 'AxialLoadAtWhichOpeningOccursDuringEccentricLoading' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AxialLoadAtWhichOpeningOccursDuringEccentricLoading
        return temp

    @property
    def bending_angle(self) -> 'float':
        """float: 'BendingAngle' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.BendingAngle
        return temp

    @property
    def bending_moment(self) -> 'float':
        """float: 'BendingMoment' is the original name of this property."""

        temp = self.wrapped.BendingMoment
        return temp

    @bending_moment.setter
    def bending_moment(self, value: 'float'):
        self.wrapped.BendingMoment = float(value) if value else 0.0

    @property
    def bending_moment_at_bolting_point(self) -> 'float':
        """float: 'BendingMomentAtBoltingPoint' is the original name of this property."""

        temp = self.wrapped.BendingMomentAtBoltingPoint
        return temp

    @bending_moment_at_bolting_point.setter
    def bending_moment_at_bolting_point(self, value: 'float'):
        self.wrapped.BendingMomentAtBoltingPoint = float(value) if value else 0.0

    @property
    def breaking_force(self) -> 'float':
        """float: 'BreakingForce' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.BreakingForce
        return temp

    @property
    def change_in_preload_due_to_thermal_expansion(self) -> 'float':
        """float: 'ChangeInPreloadDueToThermalExpansion' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ChangeInPreloadDueToThermalExpansion
        return temp

    @property
    def change_in_temperature_of_bolt(self) -> 'float':
        """float: 'ChangeInTemperatureOfBolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ChangeInTemperatureOfBolt
        return temp

    @property
    def change_in_temperature_of_clamped_parts(self) -> 'float':
        """float: 'ChangeInTemperatureOfClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ChangeInTemperatureOfClampedParts
        return temp

    @property
    def clamp_load_at_opening_limit(self) -> 'float':
        """float: 'ClampLoadAtOpeningLimit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ClampLoadAtOpeningLimit
        return temp

    @property
    def clamping_load(self) -> 'float':
        """float: 'ClampingLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ClampingLoad
        return temp

    @property
    def comparative_stress_in_assembled_state(self) -> 'float':
        """float: 'ComparativeStressInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComparativeStressInAssembledState
        return temp

    @property
    def comparative_stress_in_assembled_state_maximum_assembly_preload(self) -> 'float':
        """float: 'ComparativeStressInAssembledStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComparativeStressInAssembledStateMaximumAssemblyPreload
        return temp

    @property
    def comparative_stress_in_working_state(self) -> 'float':
        """float: 'ComparativeStressInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComparativeStressInWorkingState
        return temp

    @property
    def comparative_stress_in_working_state_maximum_assembly_preload(self) -> 'float':
        """float: 'ComparativeStressInWorkingStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComparativeStressInWorkingStateMaximumAssemblyPreload
        return temp

    @property
    def comparative_stress_in_working_state_minimum_assembly_preload(self) -> 'float':
        """float: 'ComparativeStressInWorkingStateMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComparativeStressInWorkingStateMinimumAssemblyPreload
        return temp

    @property
    def correction_factor_c1(self) -> 'float':
        """float: 'CorrectionFactorC1' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CorrectionFactorC1
        return temp

    @property
    def correction_factor_c3(self) -> 'float':
        """float: 'CorrectionFactorC3' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CorrectionFactorC3
        return temp

    @property
    def distance_between_edge_of_preloading_area_and_force_introduction_point(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'DistanceBetweenEdgeOfPreloadingAreaAndForceIntroductionPoint' is the original name of this property."""

        temp = self.wrapped.DistanceBetweenEdgeOfPreloadingAreaAndForceIntroductionPoint
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @distance_between_edge_of_preloading_area_and_force_introduction_point.setter
    def distance_between_edge_of_preloading_area_and_force_introduction_point(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.DistanceBetweenEdgeOfPreloadingAreaAndForceIntroductionPoint = value

    @property
    def distance_of_edge_bearing_point_v_from_centre(self) -> 'float':
        """float: 'DistanceOfEdgeBearingPointVFromCentre' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DistanceOfEdgeBearingPointVFromCentre
        return temp

    @property
    def distance_of_line_of_action_of_axial_load_from_centre(self) -> 'float':
        """float: 'DistanceOfLineOfActionOfAxialLoadFromCentre' is the original name of this property."""

        temp = self.wrapped.DistanceOfLineOfActionOfAxialLoadFromCentre
        return temp

    @distance_of_line_of_action_of_axial_load_from_centre.setter
    def distance_of_line_of_action_of_axial_load_from_centre(self, value: 'float'):
        self.wrapped.DistanceOfLineOfActionOfAxialLoadFromCentre = float(value) if value else 0.0

    @property
    def does_tightening_technique_exceed_yield_point(self) -> 'bool':
        """bool: 'DoesTighteningTechniqueExceedYieldPoint' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DoesTighteningTechniqueExceedYieldPoint
        return temp

    @property
    def edge_distance_of_opening_point_u(self) -> 'float':
        """float: 'EdgeDistanceOfOpeningPointU' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.EdgeDistanceOfOpeningPointU
        return temp

    @property
    def effective_diameter_of_friction_moment(self) -> 'float':
        """float: 'EffectiveDiameterOfFrictionMoment' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.EffectiveDiameterOfFrictionMoment
        return temp

    @property
    def elastic_resilience_of_bolt(self) -> 'float':
        """float: 'ElasticResilienceOfBolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElasticResilienceOfBolt
        return temp

    @property
    def elastic_resilience_of_bolt_at_room_temperature(self) -> 'float':
        """float: 'ElasticResilienceOfBoltAtRoomTemperature' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElasticResilienceOfBoltAtRoomTemperature
        return temp

    @property
    def elastic_resilience_of_bolt_in_operating_state(self) -> 'float':
        """float: 'ElasticResilienceOfBoltInOperatingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElasticResilienceOfBoltInOperatingState
        return temp

    @property
    def elastic_resilience_of_plates_at_room_temperature(self) -> 'float':
        """float: 'ElasticResilienceOfPlatesAtRoomTemperature' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElasticResilienceOfPlatesAtRoomTemperature
        return temp

    @property
    def fatigue_safety_factor_maximum_required_assembly_preload(self) -> 'float':
        """float: 'FatigueSafetyFactorMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorMaximumRequiredAssemblyPreload
        return temp

    @property
    def fatigue_safety_factor_minimum_required_assembly_preload(self) -> 'float':
        """float: 'FatigueSafetyFactorMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorMinimumRequiredAssemblyPreload
        return temp

    @property
    def fatigue_safety_factor_in_assembled_state(self) -> 'float':
        """float: 'FatigueSafetyFactorInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorInAssembledState
        return temp

    @property
    def fatigue_safety_factor_in_working_state(self) -> 'float':
        """float: 'FatigueSafetyFactorInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorInWorkingState
        return temp

    @property
    def fatigue_safety_factor_in_the_assembled_state_maximum_required_assembly_preload(self) -> 'float':
        """float: 'FatigueSafetyFactorInTheAssembledStateMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorInTheAssembledStateMaximumRequiredAssemblyPreload
        return temp

    @property
    def fatigue_safety_factor_in_the_assembled_state_minimum_required_assembly_preload(self) -> 'float':
        """float: 'FatigueSafetyFactorInTheAssembledStateMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueSafetyFactorInTheAssembledStateMinimumRequiredAssemblyPreload
        return temp

    @property
    def joint_type(self) -> '_1287.JointTypes':
        """JointTypes: 'JointType' is the original name of this property."""

        temp = self.wrapped.JointType
        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1287.JointTypes)(value) if value is not None else None

    @joint_type.setter
    def joint_type(self, value: '_1287.JointTypes'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.JointType = value

    @property
    def joint_is_to_be_designed_with_f_qmax(self) -> 'bool':
        """bool: 'JointIsToBeDesignedWithFQmax' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.JointIsToBeDesignedWithFQmax
        return temp

    @property
    def length_between_basic_solid_and_load_introduction_point_k(self) -> 'float':
        """float: 'LengthBetweenBasicSolidAndLoadIntroductionPointK' is the original name of this property."""

        temp = self.wrapped.LengthBetweenBasicSolidAndLoadIntroductionPointK
        return temp

    @length_between_basic_solid_and_load_introduction_point_k.setter
    def length_between_basic_solid_and_load_introduction_point_k(self, value: 'float'):
        self.wrapped.LengthBetweenBasicSolidAndLoadIntroductionPointK = float(value) if value else 0.0

    @property
    def limiting_slip_force(self) -> 'float':
        """float: 'LimitingSlipForce' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LimitingSlipForce
        return temp

    @property
    def limiting_surface_pressure_on_head_side(self) -> 'float':
        """float: 'LimitingSurfacePressureOnHeadSide' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LimitingSurfacePressureOnHeadSide
        return temp

    @property
    def limiting_surface_pressure_on_nut_side(self) -> 'float':
        """float: 'LimitingSurfacePressureOnNutSide' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LimitingSurfacePressureOnNutSide
        return temp

    @property
    def load_factor(self) -> 'float':
        """float: 'LoadFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactor
        return temp

    @property
    def load_factor_bending(self) -> 'float':
        """float: 'LoadFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorBending
        return temp

    @property
    def load_factor_phi_stare_k(self) -> 'float':
        """float: 'LoadFactorPhiStareK' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorPhiStareK
        return temp

    @property
    def load_factor_for_concentric_clamping(self) -> 'float':
        """float: 'LoadFactorForConcentricClamping' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorForConcentricClamping
        return temp

    @property
    def load_factor_for_concentric_clamping_in_operating_state(self) -> 'float':
        """float: 'LoadFactorForConcentricClampingInOperatingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorForConcentricClampingInOperatingState
        return temp

    @property
    def load_factor_for_eccentric_clamping(self) -> 'float':
        """float: 'LoadFactorForEccentricClamping' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorForEccentricClamping
        return temp

    @property
    def load_factor_for_eccentric_clamping_and_concentric_load_introduction(self) -> 'float':
        """float: 'LoadFactorForEccentricClampingAndConcentricLoadIntroduction' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadFactorForEccentricClampingAndConcentricLoadIntroduction
        return temp

    @property
    def load_introduction_factor(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'LoadIntroductionFactor' is the original name of this property."""

        temp = self.wrapped.LoadIntroductionFactor
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @load_introduction_factor.setter
    def load_introduction_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.LoadIntroductionFactor = value

    @property
    def load_at_minimum_yield_point(self) -> 'float':
        """float: 'LoadAtMinimumYieldPoint' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadAtMinimumYieldPoint
        return temp

    @property
    def loss_of_preload_due_to_embedding(self) -> 'float':
        """float: 'LossOfPreloadDueToEmbedding' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LossOfPreloadDueToEmbedding
        return temp

    @property
    def maximum_additional_axial_load(self) -> 'float':
        """float: 'MaximumAdditionalAxialLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumAdditionalAxialLoad
        return temp

    @property
    def maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumAssemblyPreload
        return temp

    @property
    def maximum_assembly_preload_during_assembly(self) -> 'float':
        """float: 'MaximumAssemblyPreloadDuringAssembly' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumAssemblyPreloadDuringAssembly
        return temp

    @property
    def maximum_axial_load(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MaximumAxialLoad' is the original name of this property."""

        temp = self.wrapped.MaximumAxialLoad
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @maximum_axial_load.setter
    def maximum_axial_load(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MaximumAxialLoad = value

    @property
    def maximum_head_surface_pressure_in_assembled_state(self) -> 'float':
        """float: 'MaximumHeadSurfacePressureInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumHeadSurfacePressureInAssembledState
        return temp

    @property
    def maximum_head_surface_pressure_in_working_state(self) -> 'float':
        """float: 'MaximumHeadSurfacePressureInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumHeadSurfacePressureInWorkingState
        return temp

    @property
    def maximum_nut_surface_pressure_in_assembled_state(self) -> 'float':
        """float: 'MaximumNutSurfacePressureInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumNutSurfacePressureInAssembledState
        return temp

    @property
    def maximum_nut_surface_pressure_in_working_state(self) -> 'float':
        """float: 'MaximumNutSurfacePressureInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumNutSurfacePressureInWorkingState
        return temp

    @property
    def maximum_preload(self) -> 'float':
        """float: 'MaximumPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumPreload
        return temp

    @property
    def maximum_preload_maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumPreloadMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumPreloadMaximumAssemblyPreload
        return temp

    @property
    def maximum_preload_minimum_assembly_preload(self) -> 'float':
        """float: 'MaximumPreloadMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumPreloadMinimumAssemblyPreload
        return temp

    @property
    def maximum_preload_in_assembled_state_maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumPreloadInAssembledStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumPreloadInAssembledStateMaximumAssemblyPreload
        return temp

    @property
    def maximum_pressure_to_be_sealed(self) -> 'float':
        """float: 'MaximumPressureToBeSealed' is the original name of this property."""

        temp = self.wrapped.MaximumPressureToBeSealed
        return temp

    @maximum_pressure_to_be_sealed.setter
    def maximum_pressure_to_be_sealed(self, value: 'float'):
        self.wrapped.MaximumPressureToBeSealed = float(value) if value else 0.0

    @property
    def maximum_relieving_load_of_plates(self) -> 'float':
        """float: 'MaximumRelievingLoadOfPlates' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumRelievingLoadOfPlates
        return temp

    @property
    def maximum_stress_in_bending_tension_of_bolt_thread(self) -> 'float':
        """float: 'MaximumStressInBendingTensionOfBoltThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumStressInBendingTensionOfBoltThread
        return temp

    @property
    def maximum_surface_pressure(self) -> 'float':
        """float: 'MaximumSurfacePressure' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressure
        return temp

    @property
    def maximum_surface_pressure_in_assembled_state(self) -> 'float':
        """float: 'MaximumSurfacePressureInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressureInAssembledState
        return temp

    @property
    def maximum_surface_pressure_in_assembled_state_maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumSurfacePressureInAssembledStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressureInAssembledStateMaximumAssemblyPreload
        return temp

    @property
    def maximum_surface_pressure_in_working_state(self) -> 'float':
        """float: 'MaximumSurfacePressureInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressureInWorkingState
        return temp

    @property
    def maximum_surface_pressure_in_working_state_maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumSurfacePressureInWorkingStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressureInWorkingStateMaximumAssemblyPreload
        return temp

    @property
    def maximum_surface_pressure_in_working_state_minimum_assembly_preload(self) -> 'float':
        """float: 'MaximumSurfacePressureInWorkingStateMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumSurfacePressureInWorkingStateMinimumAssemblyPreload
        return temp

    @property
    def maximum_tensile_stress(self) -> 'float':
        """float: 'MaximumTensileStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumTensileStress
        return temp

    @property
    def maximum_tensile_stress_in_working_state_maximum_assembly_preload(self) -> 'float':
        """float: 'MaximumTensileStressInWorkingStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumTensileStressInWorkingStateMaximumAssemblyPreload
        return temp

    @property
    def maximum_tensile_stress_in_working_state_minimum_assembly_preload(self) -> 'float':
        """float: 'MaximumTensileStressInWorkingStateMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumTensileStressInWorkingStateMinimumAssemblyPreload
        return temp

    @property
    def maximum_torque_about_bolt_axis(self) -> 'float':
        """float: 'MaximumTorqueAboutBoltAxis' is the original name of this property."""

        temp = self.wrapped.MaximumTorqueAboutBoltAxis
        return temp

    @maximum_torque_about_bolt_axis.setter
    def maximum_torque_about_bolt_axis(self, value: 'float'):
        self.wrapped.MaximumTorqueAboutBoltAxis = float(value) if value else 0.0

    @property
    def maximum_torsional_moment(self) -> 'float':
        """float: 'MaximumTorsionalMoment' is the original name of this property."""

        temp = self.wrapped.MaximumTorsionalMoment
        return temp

    @maximum_torsional_moment.setter
    def maximum_torsional_moment(self, value: 'float'):
        self.wrapped.MaximumTorsionalMoment = float(value) if value else 0.0

    @property
    def maximum_torsional_stress(self) -> 'float':
        """float: 'MaximumTorsionalStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumTorsionalStress
        return temp

    @property
    def maximum_torsional_stress_due_to_fq(self) -> 'float':
        """float: 'MaximumTorsionalStressDueToFQ' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumTorsionalStressDueToFQ
        return temp

    @property
    def maximum_transverse_load(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MaximumTransverseLoad' is the original name of this property."""

        temp = self.wrapped.MaximumTransverseLoad
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @maximum_transverse_load.setter
    def maximum_transverse_load(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MaximumTransverseLoad = value

    @property
    def minimum_additional_axial_load(self) -> 'float':
        """float: 'MinimumAdditionalAxialLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumAdditionalAxialLoad
        return temp

    @property
    def minimum_assembly_preload(self) -> 'float':
        """float: 'MinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumAssemblyPreload
        return temp

    @property
    def minimum_assembly_preload_during_assembly(self) -> 'float':
        """float: 'MinimumAssemblyPreloadDuringAssembly' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumAssemblyPreloadDuringAssembly
        return temp

    @property
    def minimum_axial_load(self) -> 'float':
        """float: 'MinimumAxialLoad' is the original name of this property."""

        temp = self.wrapped.MinimumAxialLoad
        return temp

    @minimum_axial_load.setter
    def minimum_axial_load(self, value: 'float'):
        self.wrapped.MinimumAxialLoad = float(value) if value else 0.0

    @property
    def minimum_clamp_load_for_ensuring_a_sealing_function(self) -> 'float':
        """float: 'MinimumClampLoadForEnsuringASealingFunction' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumClampLoadForEnsuringASealingFunction
        return temp

    @property
    def minimum_clamp_load_at_the_opening_limit(self) -> 'float':
        """float: 'MinimumClampLoadAtTheOpeningLimit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumClampLoadAtTheOpeningLimit
        return temp

    @property
    def minimum_clamp_load_for_transmitting_transverse_load(self) -> 'float':
        """float: 'MinimumClampLoadForTransmittingTransverseLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumClampLoadForTransmittingTransverseLoad
        return temp

    @property
    def minimum_effective_length_of_engagement(self) -> 'float':
        """float: 'MinimumEffectiveLengthOfEngagement' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumEffectiveLengthOfEngagement
        return temp

    @property
    def minimum_length_of_engagement(self) -> 'float':
        """float: 'MinimumLengthOfEngagement' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumLengthOfEngagement
        return temp

    @property
    def minimum_nominal_diameter(self) -> 'float':
        """float: 'MinimumNominalDiameter' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumNominalDiameter
        return temp

    @property
    def minimum_preload(self) -> 'float':
        """float: 'MinimumPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumPreload
        return temp

    @property
    def minimum_required_clamping_force(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MinimumRequiredClampingForce' is the original name of this property."""

        temp = self.wrapped.MinimumRequiredClampingForce
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @minimum_required_clamping_force.setter
    def minimum_required_clamping_force(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MinimumRequiredClampingForce = value

    @property
    def minimum_residual_clamp_load(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MinimumResidualClampLoad' is the original name of this property."""

        temp = self.wrapped.MinimumResidualClampLoad
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @minimum_residual_clamp_load.setter
    def minimum_residual_clamp_load(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MinimumResidualClampLoad = value

    @property
    def minimum_residual_clamp_load_maximum_assembly_preload(self) -> 'float':
        """float: 'MinimumResidualClampLoadMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumResidualClampLoadMaximumAssemblyPreload
        return temp

    @property
    def minimum_residual_clamp_load_minimum_assembly_preload(self) -> 'float':
        """float: 'MinimumResidualClampLoadMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumResidualClampLoadMinimumAssemblyPreload
        return temp

    @property
    def minimum_residual_clamp_load_in_assembled_state(self) -> 'float':
        """float: 'MinimumResidualClampLoadInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumResidualClampLoadInAssembledState
        return temp

    @property
    def minimum_stress_in_bending_tension_of_bolt_thread(self) -> 'float':
        """float: 'MinimumStressInBendingTensionOfBoltThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumStressInBendingTensionOfBoltThread
        return temp

    @property
    def number_of_alternating_cycles_during_continuous_loading(self) -> 'float':
        """float: 'NumberOfAlternatingCyclesDuringContinuousLoading' is the original name of this property."""

        temp = self.wrapped.NumberOfAlternatingCyclesDuringContinuousLoading
        return temp

    @number_of_alternating_cycles_during_continuous_loading.setter
    def number_of_alternating_cycles_during_continuous_loading(self, value: 'float'):
        self.wrapped.NumberOfAlternatingCyclesDuringContinuousLoading = float(value) if value else 0.0

    @property
    def number_of_alternating_cycles_during_loading_within_fatigue_range(self) -> 'float':
        """float: 'NumberOfAlternatingCyclesDuringLoadingWithinFatigueRange' is the original name of this property."""

        temp = self.wrapped.NumberOfAlternatingCyclesDuringLoadingWithinFatigueRange
        return temp

    @number_of_alternating_cycles_during_loading_within_fatigue_range.setter
    def number_of_alternating_cycles_during_loading_within_fatigue_range(self, value: 'float'):
        self.wrapped.NumberOfAlternatingCyclesDuringLoadingWithinFatigueRange = float(value) if value else 0.0

    @property
    def number_of_bearing_areas(self) -> 'int':
        """int: 'NumberOfBearingAreas' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NumberOfBearingAreas
        return temp

    @property
    def number_of_steps_for_f_mmax_table_a7(self) -> 'int':
        """int: 'NumberOfStepsForFMmaxTableA7' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NumberOfStepsForFMmaxTableA7
        return temp

    @property
    def number_of_steps_for_f_mmin_table_a7(self) -> 'int':
        """int: 'NumberOfStepsForFMminTableA7' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NumberOfStepsForFMminTableA7
        return temp

    @property
    def operating_temperature_of_bolt(self) -> 'float':
        """float: 'OperatingTemperatureOfBolt' is the original name of this property."""

        temp = self.wrapped.OperatingTemperatureOfBolt
        return temp

    @operating_temperature_of_bolt.setter
    def operating_temperature_of_bolt(self, value: 'float'):
        self.wrapped.OperatingTemperatureOfBolt = float(value) if value else 0.0

    @property
    def operating_temperature_of_clamped_parts(self) -> 'float':
        """float: 'OperatingTemperatureOfClampedParts' is the original name of this property."""

        temp = self.wrapped.OperatingTemperatureOfClampedParts
        return temp

    @operating_temperature_of_clamped_parts.setter
    def operating_temperature_of_clamped_parts(self, value: 'float'):
        self.wrapped.OperatingTemperatureOfClampedParts = float(value) if value else 0.0

    @property
    def parameter_of_circle_equation_mk(self) -> 'float':
        """float: 'ParameterOfCircleEquationMK' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ParameterOfCircleEquationMK
        return temp

    @property
    def parameter_of_circle_equation_nk(self) -> 'float':
        """float: 'ParameterOfCircleEquationNK' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ParameterOfCircleEquationNK
        return temp

    @property
    def permissible_assembly_preload(self) -> 'float':
        """float: 'PermissibleAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PermissibleAssemblyPreload
        return temp

    @property
    def permissible_assembly_preload_assembled_state(self) -> 'float':
        """float: 'PermissibleAssemblyPreloadAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PermissibleAssemblyPreloadAssembledState
        return temp

    @property
    def permissible_shearing_force_of_bolt(self) -> 'float':
        """float: 'PermissibleShearingForceOfBolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PermissibleShearingForceOfBolt
        return temp

    @property
    def permitted_assembly_reduced_stress(self) -> 'float':
        """float: 'PermittedAssemblyReducedStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PermittedAssemblyReducedStress
        return temp

    @property
    def plastic_deformation_due_to_embedding(self) -> 'float':
        """float: 'PlasticDeformationDueToEmbedding' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PlasticDeformationDueToEmbedding
        return temp

    @property
    def polar_moment_of_resistance(self) -> 'float':
        """float: 'PolarMomentOfResistance' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PolarMomentOfResistance
        return temp

    @property
    def preload(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'Preload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Preload
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @property
    def preload_at_opening_limit(self) -> 'float':
        """float: 'PreloadAtOpeningLimit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PreloadAtOpeningLimit
        return temp

    @property
    def preload_at_room_temperature(self) -> 'float':
        """float: 'PreloadAtRoomTemperature' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PreloadAtRoomTemperature
        return temp

    @property
    def preload_in_assembled_state(self) -> 'float':
        """float: 'PreloadInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PreloadInAssembledState
        return temp

    @property
    def present_effective_length_of_engagement(self) -> 'float':
        """float: 'PresentEffectiveLengthOfEngagement' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PresentEffectiveLengthOfEngagement
        return temp

    @property
    def present_length_of_engagement(self) -> 'float':
        """float: 'PresentLengthOfEngagement' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PresentLengthOfEngagement
        return temp

    @property
    def proportion_of_tightening_torque_in_thread(self) -> 'float':
        """float: 'ProportionOfTighteningTorqueInThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ProportionOfTighteningTorqueInThread
        return temp

    @property
    def relieving_load_of_plates(self) -> 'float':
        """float: 'RelievingLoadOfPlates' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelievingLoadOfPlates
        return temp

    @property
    def residual_transverse_load(self) -> 'float':
        """float: 'ResidualTransverseLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ResidualTransverseLoad
        return temp

    @property
    def resulting_moment_in_clamping_area(self) -> 'float':
        """float: 'ResultingMomentInClampingArea' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ResultingMomentInClampingArea
        return temp

    @property
    def shearing_cross_section_of_bolt_thread(self) -> 'float':
        """float: 'ShearingCrossSectionOfBoltThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ShearingCrossSectionOfBoltThread
        return temp

    @property
    def shearing_cross_section_of_nut_thread(self) -> 'float':
        """float: 'ShearingCrossSectionOfNutThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ShearingCrossSectionOfNutThread
        return temp

    @property
    def shearing_safety_factor(self) -> 'float':
        """float: 'ShearingSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ShearingSafetyFactor
        return temp

    @property
    def slipping_safety_factor(self) -> 'float':
        """float: 'SlippingSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactor
        return temp

    @property
    def slipping_safety_factor_maximum_required_assembly_preload(self) -> 'float':
        """float: 'SlippingSafetyFactorMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactorMaximumRequiredAssemblyPreload
        return temp

    @property
    def slipping_safety_factor_minimum_required_assembly_preload(self) -> 'float':
        """float: 'SlippingSafetyFactorMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactorMinimumRequiredAssemblyPreload
        return temp

    @property
    def slipping_safety_factor_in_the_assembled_state(self) -> 'float':
        """float: 'SlippingSafetyFactorInTheAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactorInTheAssembledState
        return temp

    @property
    def slipping_safety_factor_in_the_assembled_state_maximum_assembly_preload(self) -> 'float':
        """float: 'SlippingSafetyFactorInTheAssembledStateMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactorInTheAssembledStateMaximumAssemblyPreload
        return temp

    @property
    def slipping_safety_factor_in_the_assembled_state_minimum_assembly_preload(self) -> 'float':
        """float: 'SlippingSafetyFactorInTheAssembledStateMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SlippingSafetyFactorInTheAssembledStateMinimumAssemblyPreload
        return temp

    @property
    def strength_ratio(self) -> 'float':
        """float: 'StrengthRatio' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StrengthRatio
        return temp

    @property
    def stress_amplitude_of_endurance_limit_sg(self) -> 'float':
        """float: 'StressAmplitudeOfEnduranceLimitSG' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfEnduranceLimitSG
        return temp

    @property
    def stress_amplitude_of_endurance_limit_sg_maximum_assembly_preload(self) -> 'float':
        """float: 'StressAmplitudeOfEnduranceLimitSGMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfEnduranceLimitSGMaximumAssemblyPreload
        return temp

    @property
    def stress_amplitude_of_endurance_limit_sg_minimum_assembly_preload(self) -> 'float':
        """float: 'StressAmplitudeOfEnduranceLimitSGMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfEnduranceLimitSGMinimumAssemblyPreload
        return temp

    @property
    def stress_amplitude_of_endurance_limit_sv(self) -> 'float':
        """float: 'StressAmplitudeOfEnduranceLimitSV' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfEnduranceLimitSV
        return temp

    @property
    def stress_amplitude_of_fatigue_strength_sg(self) -> 'float':
        """float: 'StressAmplitudeOfFatigueStrengthSG' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfFatigueStrengthSG
        return temp

    @property
    def stress_amplitude_of_fatigue_strength_sg_maximum_assembly_preload(self) -> 'float':
        """float: 'StressAmplitudeOfFatigueStrengthSGMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfFatigueStrengthSGMaximumAssemblyPreload
        return temp

    @property
    def stress_amplitude_of_fatigue_strength_sg_minimum_assembly_preload(self) -> 'float':
        """float: 'StressAmplitudeOfFatigueStrengthSGMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfFatigueStrengthSGMinimumAssemblyPreload
        return temp

    @property
    def stress_amplitude_of_fatigue_strength_sv(self) -> 'float':
        """float: 'StressAmplitudeOfFatigueStrengthSV' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAmplitudeOfFatigueStrengthSV
        return temp

    @property
    def stress_in_bending_tension_of_bolt_thread(self) -> 'float':
        """float: 'StressInBendingTensionOfBoltThread' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressInBendingTensionOfBoltThread
        return temp

    @property
    def stripping_force(self) -> 'float':
        """float: 'StrippingForce' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StrippingForce
        return temp

    @property
    def surface_pressure_safety_factor(self) -> 'float':
        """float: 'SurfacePressureSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactor
        return temp

    @property
    def surface_pressure_safety_factor_maximum_required_assembly_preload(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorMaximumRequiredAssemblyPreload
        return temp

    @property
    def surface_pressure_safety_factor_minimum_required_assembly_preload(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorMinimumRequiredAssemblyPreload
        return temp

    @property
    def surface_pressure_safety_factor_in_assembled_state(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorInAssembledState
        return temp

    @property
    def surface_pressure_safety_factor_in_working_state(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorInWorkingState
        return temp

    @property
    def surface_pressure_safety_factor_in_the_assembled_state_minimum_required_assembly_preload(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorInTheAssembledStateMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorInTheAssembledStateMinimumRequiredAssemblyPreload
        return temp

    @property
    def surface_pressure_safety_factor_on_head_side(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorOnHeadSide' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorOnHeadSide
        return temp

    @property
    def surface_pressure_safety_factor_on_head_side_in_working_state(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorOnHeadSideInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorOnHeadSideInWorkingState
        return temp

    @property
    def surface_pressure_safety_factor_on_nut_side(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorOnNutSide' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorOnNutSide
        return temp

    @property
    def surface_pressure_safety_factor_on_nut_side_in_working_state(self) -> 'float':
        """float: 'SurfacePressureSafetyFactorOnNutSideInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePressureSafetyFactorOnNutSideInWorkingState
        return temp

    @property
    def tabular_assembly_preload(self) -> 'float':
        """float: 'TabularAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TabularAssemblyPreload
        return temp

    @property
    def tabular_tightening_torque(self) -> 'float':
        """float: 'TabularTighteningTorque' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TabularTighteningTorque
        return temp

    @property
    def tensile_stress_due_to_assembly_preload(self) -> 'float':
        """float: 'TensileStressDueToAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TensileStressDueToAssemblyPreload
        return temp

    @property
    def theoretical_load_factor(self) -> 'float':
        """float: 'TheoreticalLoadFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TheoreticalLoadFactor
        return temp

    @property
    def tightening_factor(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'TighteningFactor' is the original name of this property."""

        temp = self.wrapped.TighteningFactor
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @tightening_factor.setter
    def tightening_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.TighteningFactor = value

    @property
    def tightening_technique(self) -> '_1293.TighteningTechniques':
        """TighteningTechniques: 'TighteningTechnique' is the original name of this property."""

        temp = self.wrapped.TighteningTechnique
        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1293.TighteningTechniques)(value) if value is not None else None

    @tightening_technique.setter
    def tightening_technique(self, value: '_1293.TighteningTechniques'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.TighteningTechnique = value

    @property
    def tightening_torque(self) -> 'float':
        """float: 'TighteningTorque' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TighteningTorque
        return temp

    @property
    def tightening_torque_maximum_assembly_preload(self) -> 'float':
        """float: 'TighteningTorqueMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TighteningTorqueMaximumAssemblyPreload
        return temp

    @property
    def tightening_torque_minimum_assembly_preload(self) -> 'float':
        """float: 'TighteningTorqueMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TighteningTorqueMinimumAssemblyPreload
        return temp

    @property
    def torsional_stress_in_assembled_state(self) -> 'float':
        """float: 'TorsionalStressInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TorsionalStressInAssembledState
        return temp

    @property
    def total_bending_moment(self) -> 'float':
        """float: 'TotalBendingMoment' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBendingMoment
        return temp

    @property
    def total_bending_moment_in_bolt(self) -> 'float':
        """float: 'TotalBendingMomentInBolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBendingMomentInBolt
        return temp

    @property
    def total_bending_moment_in_plates(self) -> 'float':
        """float: 'TotalBendingMomentInPlates' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBendingMomentInPlates
        return temp

    @property
    def total_bolt_load(self) -> 'float':
        """float: 'TotalBoltLoad' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBoltLoad
        return temp

    @property
    def total_bolt_load_maximum_assembly_preload(self) -> 'float':
        """float: 'TotalBoltLoadMaximumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBoltLoadMaximumAssemblyPreload
        return temp

    @property
    def total_bolt_load_minimum_assembly_preload(self) -> 'float':
        """float: 'TotalBoltLoadMinimumAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalBoltLoadMinimumAssemblyPreload
        return temp

    @property
    def yield_point_safety_factor_in_assembled_state(self) -> 'float':
        """float: 'YieldPointSafetyFactorInAssembledState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.YieldPointSafetyFactorInAssembledState
        return temp

    @property
    def yield_point_safety_factor_in_assembled_state_maximum_required_assembly_preload(self) -> 'float':
        """float: 'YieldPointSafetyFactorInAssembledStateMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.YieldPointSafetyFactorInAssembledStateMaximumRequiredAssemblyPreload
        return temp

    @property
    def yield_point_safety_factor_in_working_state(self) -> 'float':
        """float: 'YieldPointSafetyFactorInWorkingState' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.YieldPointSafetyFactorInWorkingState
        return temp

    @property
    def yield_point_safety_factor_in_working_state_maximum_required_assembly_preload(self) -> 'float':
        """float: 'YieldPointSafetyFactorInWorkingStateMaximumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.YieldPointSafetyFactorInWorkingStateMaximumRequiredAssemblyPreload
        return temp

    @property
    def yield_point_safety_factor_in_working_state_minimum_required_assembly_preload(self) -> 'float':
        """float: 'YieldPointSafetyFactorInWorkingStateMinimumRequiredAssemblyPreload' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.YieldPointSafetyFactorInWorkingStateMinimumRequiredAssemblyPreload
        return temp

    @property
    def bolt(self) -> '_1283.DetailedBoltDesign':
        """DetailedBoltDesign: 'Bolt' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Bolt
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def load_vector(self) -> 'Vector3D':
        """Vector3D: 'LoadVector' is the original name of this property."""

        temp = self.wrapped.LoadVector
        value = conversion.pn_to_mp_vector3d(temp)
        return value

    @load_vector.setter
    def load_vector(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.LoadVector = value

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames
        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result



"""_5306.py

CycloidalAssemblyCompoundMultibodyDynamicsAnalysis
"""


from typing import List

from mastapy.system_model.part_model.cycloidal import _2317
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5157
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5361
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_ASSEMBLY_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'CycloidalAssemblyCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalAssemblyCompoundMultibodyDynamicsAnalysis',)


class CycloidalAssemblyCompoundMultibodyDynamicsAnalysis(_5361.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis):
    """CycloidalAssemblyCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _CYCLOIDAL_ASSEMBLY_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalAssemblyCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2317.CycloidalAssembly':
        """CycloidalAssembly: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2317.CycloidalAssembly':
        """CycloidalAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5157.CycloidalAssemblyMultibodyDynamicsAnalysis]':
        """List[CycloidalAssemblyMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5157.CycloidalAssemblyMultibodyDynamicsAnalysis]':
        """List[CycloidalAssemblyMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_1344.py

SurfaceToSurfaceContact
"""


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SURFACE_TO_SURFACE_CONTACT = python_net_import('SMT.MastaAPI.MathUtility.StiffnessCalculators', 'SurfaceToSurfaceContact')


__docformat__ = 'restructuredtext en'
__all__ = ('SurfaceToSurfaceContact',)


class SurfaceToSurfaceContact(_0.APIBase):
    """SurfaceToSurfaceContact

    This is a mastapy class.
    """

    TYPE = _SURFACE_TO_SURFACE_CONTACT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SurfaceToSurfaceContact.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def normal_deflection(self) -> 'float':
        """float: 'NormalDeflection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalDeflection
        return temp

    @property
    def normal_force(self) -> 'float':
        """float: 'NormalForce' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalForce
        return temp

    @property
    def normal_stiffness(self) -> 'float':
        """float: 'NormalStiffness' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalStiffness
        return temp

    @property
    def surface_penetration(self) -> 'float':
        """float: 'SurfacePenetration' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SurfacePenetration
        return temp



"""_4590.py

WormGearSetCompoundModalAnalysis
"""


from typing import List

from mastapy.system_model.part_model.gears import _2301
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses import _4449
from mastapy.system_model.analyses_and_results.modal_analyses.compound import _4588, _4589, _4525
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_COMPOUND_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound', 'WormGearSetCompoundModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetCompoundModalAnalysis',)


class WormGearSetCompoundModalAnalysis(_4525.GearSetCompoundModalAnalysis):
    """WormGearSetCompoundModalAnalysis

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_SET_COMPOUND_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetCompoundModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2301.WormGearSet':
        """WormGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2301.WormGearSet':
        """WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_4449.WormGearSetModalAnalysis]':
        """List[WormGearSetModalAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def worm_gears_compound_modal_analysis(self) -> 'List[_4588.WormGearCompoundModalAnalysis]':
        """List[WormGearCompoundModalAnalysis]: 'WormGearsCompoundModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormGearsCompoundModalAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def worm_meshes_compound_modal_analysis(self) -> 'List[_4589.WormGearMeshCompoundModalAnalysis]':
        """List[WormGearMeshCompoundModalAnalysis]: 'WormMeshesCompoundModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormMeshesCompoundModalAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_4449.WormGearSetModalAnalysis]':
        """List[WormGearSetModalAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_1355.py

ParetoOptimisationOutput
"""


from mastapy._internal import constructor
from mastapy.math_utility.optimisation import _1361
from mastapy._internal.python_net import python_net_import

_PARETO_OPTIMISATION_OUTPUT = python_net_import('SMT.MastaAPI.MathUtility.Optimisation', 'ParetoOptimisationOutput')


__docformat__ = 'restructuredtext en'
__all__ = ('ParetoOptimisationOutput',)


class ParetoOptimisationOutput(_1361.ParetoOptimistaionVariable):
    """ParetoOptimisationOutput

    This is a mastapy class.
    """

    TYPE = _PARETO_OPTIMISATION_OUTPUT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ParetoOptimisationOutput.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def percent(self) -> 'float':
        """float: 'Percent' is the original name of this property."""

        temp = self.wrapped.Percent
        return temp

    @percent.setter
    def percent(self, value: 'float'):
        self.wrapped.Percent = float(value) if value else 0.0

    @property
    def exclude_from_dominant_candidates_search(self) -> 'bool':
        """bool: 'ExcludeFromDominantCandidatesSearch' is the original name of this property."""

        temp = self.wrapped.ExcludeFromDominantCandidatesSearch
        return temp

    @exclude_from_dominant_candidates_search.setter
    def exclude_from_dominant_candidates_search(self, value: 'bool'):
        self.wrapped.ExcludeFromDominantCandidatesSearch = bool(value) if value else False

    @property
    def use_original_design_value(self) -> 'bool':
        """bool: 'UseOriginalDesignValue' is the original name of this property."""

        temp = self.wrapped.UseOriginalDesignValue
        return temp

    @use_original_design_value.setter
    def use_original_design_value(self, value: 'bool'):
        self.wrapped.UseOriginalDesignValue = bool(value) if value else False



"""_2476.py

CVTBeltConnectionSystemDeflection
"""


from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _2024
from mastapy.system_model.analyses_and_results.power_flows import _3814
from mastapy.system_model.analyses_and_results.system_deflections import _2443
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'CVTBeltConnectionSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTBeltConnectionSystemDeflection',)


class CVTBeltConnectionSystemDeflection(_2443.BeltConnectionSystemDeflection):
    """CVTBeltConnectionSystemDeflection

    This is a mastapy class.
    """

    TYPE = _CVT_BELT_CONNECTION_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTBeltConnectionSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def belt_clamping_force_safety_factor(self) -> 'float':
        """float: 'BeltClampingForceSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.BeltClampingForceSafetyFactor
        return temp

    @property
    def minimum_required_clamping_force(self) -> 'float':
        """float: 'MinimumRequiredClampingForce' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MinimumRequiredClampingForce
        return temp

    @property
    def pump_efficiency(self) -> 'float':
        """float: 'PumpEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PumpEfficiency
        return temp

    @property
    def total_efficiency(self) -> 'float':
        """float: 'TotalEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalEfficiency
        return temp

    @property
    def variator_efficiency(self) -> 'float':
        """float: 'VariatorEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.VariatorEfficiency
        return temp

    @property
    def connection_design(self) -> '_2024.CVTBeltConnection':
        """CVTBeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def power_flow_results(self) -> '_3814.CVTBeltConnectionPowerFlow':
        """CVTBeltConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PowerFlowResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_827.py

CylindricalMeshLoadDistributionAtRotation
"""


from typing import List

from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1075
from mastapy._internal import constructor, conversion
from mastapy.gears.ltca.cylindrical import _824
from mastapy.gears.ltca import _808
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_MESH_LOAD_DISTRIBUTION_AT_ROTATION = python_net_import('SMT.MastaAPI.Gears.LTCA.Cylindrical', 'CylindricalMeshLoadDistributionAtRotation')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalMeshLoadDistributionAtRotation',)


class CylindricalMeshLoadDistributionAtRotation(_808.GearMeshLoadDistributionAtRotation):
    """CylindricalMeshLoadDistributionAtRotation

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_MESH_LOAD_DISTRIBUTION_AT_ROTATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalMeshLoadDistributionAtRotation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def mesh_alignment(self) -> '_1075.MeshAlignment':
        """MeshAlignment: 'MeshAlignment' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshAlignment
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def loaded_contact_lines(self) -> 'List[_824.CylindricalGearMeshLoadedContactLine]':
        """List[CylindricalGearMeshLoadedContactLine]: 'LoadedContactLines' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadedContactLines
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_5500.py

HypoidGearMeshHarmonicAnalysis
"""


from mastapy.system_model.connections_and_sockets.gears import _2066
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6632
from mastapy.system_model.analyses_and_results.system_deflections import _2507
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5418
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_MESH_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses', 'HypoidGearMeshHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearMeshHarmonicAnalysis',)


class HypoidGearMeshHarmonicAnalysis(_5418.AGMAGleasonConicalGearMeshHarmonicAnalysis):
    """HypoidGearMeshHarmonicAnalysis

    This is a mastapy class.
    """

    TYPE = _HYPOID_GEAR_MESH_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearMeshHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2066.HypoidGearMesh':
        """HypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_load_case(self) -> '_6632.HypoidGearMeshLoadCase':
        """HypoidGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def system_deflection_results(self) -> '_2507.HypoidGearMeshSystemDeflection':
        """HypoidGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SystemDeflectionResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_2961.py

SpiralBevelGearSetCompoundSteadyStateSynchronousResponse
"""


from typing import List

from mastapy.system_model.part_model.gears import _2293
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _2828
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.compound import _2959, _2960, _2878
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses.Compound', 'SpiralBevelGearSetCompoundSteadyStateSynchronousResponse')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelGearSetCompoundSteadyStateSynchronousResponse',)


class SpiralBevelGearSetCompoundSteadyStateSynchronousResponse(_2878.BevelGearSetCompoundSteadyStateSynchronousResponse):
    """SpiralBevelGearSetCompoundSteadyStateSynchronousResponse

    This is a mastapy class.
    """

    TYPE = _SPIRAL_BEVEL_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelGearSetCompoundSteadyStateSynchronousResponse.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2293.SpiralBevelGearSet':
        """SpiralBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2293.SpiralBevelGearSet':
        """SpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_2828.SpiralBevelGearSetSteadyStateSynchronousResponse]':
        """List[SpiralBevelGearSetSteadyStateSynchronousResponse]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def spiral_bevel_gears_compound_steady_state_synchronous_response(self) -> 'List[_2959.SpiralBevelGearCompoundSteadyStateSynchronousResponse]':
        """List[SpiralBevelGearCompoundSteadyStateSynchronousResponse]: 'SpiralBevelGearsCompoundSteadyStateSynchronousResponse' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SpiralBevelGearsCompoundSteadyStateSynchronousResponse
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def spiral_bevel_meshes_compound_steady_state_synchronous_response(self) -> 'List[_2960.SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse]':
        """List[SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse]: 'SpiralBevelMeshesCompoundSteadyStateSynchronousResponse' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SpiralBevelMeshesCompoundSteadyStateSynchronousResponse
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_2828.SpiralBevelGearSetSteadyStateSynchronousResponse]':
        """List[SpiralBevelGearSetSteadyStateSynchronousResponse]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_496.py

ToothFlankFractureAnalysisPointN1457
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._math.vector_2d import Vector2D
from mastapy.gears.rating.cylindrical.iso6336 import _498
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_TOOTH_FLANK_FRACTURE_ANALYSIS_POINT_N1457 = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336', 'ToothFlankFractureAnalysisPointN1457')


__docformat__ = 'restructuredtext en'
__all__ = ('ToothFlankFractureAnalysisPointN1457',)


class ToothFlankFractureAnalysisPointN1457(_0.APIBase):
    """ToothFlankFractureAnalysisPointN1457

    This is a mastapy class.
    """

    TYPE = _TOOTH_FLANK_FRACTURE_ANALYSIS_POINT_N1457

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ToothFlankFractureAnalysisPointN1457.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def depth_from_surface(self) -> 'float':
        """float: 'DepthFromSurface' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DepthFromSurface
        return temp

    @property
    def fatigue_damage(self) -> 'float':
        """float: 'FatigueDamage' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FatigueDamage
        return temp

    @property
    def hardness_conversion_factor(self) -> 'float':
        """float: 'HardnessConversionFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HardnessConversionFactor
        return temp

    @property
    def local_material_hardness(self) -> 'float':
        """float: 'LocalMaterialHardness' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LocalMaterialHardness
        return temp

    @property
    def local_permissible_shear_strength(self) -> 'float':
        """float: 'LocalPermissibleShearStrength' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LocalPermissibleShearStrength
        return temp

    @property
    def maximum_equivalent_stress(self) -> 'float':
        """float: 'MaximumEquivalentStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MaximumEquivalentStress
        return temp

    @property
    def normalised_depth_from_surface(self) -> 'float':
        """float: 'NormalisedDepthFromSurface' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalisedDepthFromSurface
        return temp

    @property
    def tangential_component_of_compressive_residual_stresses(self) -> 'float':
        """float: 'TangentialComponentOfCompressiveResidualStresses' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TangentialComponentOfCompressiveResidualStresses
        return temp

    @property
    def coordinates(self) -> 'Vector2D':
        """Vector2D: 'Coordinates' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Coordinates
        value = conversion.pn_to_mp_vector2d(temp)
        return value

    @property
    def stress_analysis_with_maximum_equivalent_stress(self) -> '_498.ToothFlankFractureStressStepAtAnalysisPointN1457':
        """ToothFlankFractureStressStepAtAnalysisPointN1457: 'StressAnalysisWithMaximumEquivalentStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressAnalysisWithMaximumEquivalentStress
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def stress_history(self) -> 'List[_498.ToothFlankFractureStressStepAtAnalysisPointN1457]':
        """List[ToothFlankFractureStressStepAtAnalysisPointN1457]: 'StressHistory' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StressHistory
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_3003.py

BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft
"""


from mastapy.system_model.part_model.gears import _2266
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import _3002
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_PLANET_GEAR_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft', 'BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft',)


class BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft(_3002.BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft):
    """BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE = _BEVEL_DIFFERENTIAL_PLANET_GEAR_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2266.BevelDifferentialPlanetGear':
        """BevelDifferentialPlanetGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None
